Skip to main contentCrate rquickjs_macro
Source - embed
- A macro for embedding JavaScript code into a binary.
- class
- An attribute for implementing
JsClass for a Rust type. - exotic
- An attribute for implementing exotic methods for a class.
- function
- A attribute for implementing
IntoJsFunc for a certain function. - methods
- A attribute for implementing methods for a class.
- module
- An attribute which generates code for exporting a module to Rust.
- FromJs
- A macro for deriving
FromJs for plain-data structs. - IntoJs
- A macro for deriving
IntoJs for plain-data structs. - JsLifetime
- A Macro for auto deriving the JsLifetime trait.
- Trace
- A macro for auto deriving the trace trait.